CloudWatchLargeMessages enum

Enum representing what should happen to messages that are too big to be sent as a single message. This limit is 1048550 utf8 bytes

truncate: Replace the middle of the message with "...", making it fit within the max message size. This is the default value.

ignore: Ignore large messages. They will not be sent

split: Split large messages into multiple smaller messages and send them

error: Throw an error when a large message is encountered

Inheritance
Available extensions

Values

truncate → const CloudWatchLargeMessages

Replace the middle of the message with "...", making it fit within the max message size.

ignore → const CloudWatchLargeMessages

Ignore large messages. They will not be sent

split → const CloudWatchLargeMessages

Split large messages into multiple smaller messages and send them

error → const CloudWatchLargeMessages

Throw an error when a large message is encountered

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloudWatchLargeMessages>
A constant List of the values in this enum, in order of their declaration.