logMany method
Sends a log to AWS
Sends a list of strings logStrings to AWS to be added to the CloudWatch logs
Note: using logMany will result in all logs having the same timestamp
Throws a CloudWatchException if groupName or streamName are not initialized or if aws returns an error.
Implementation
Future<void> logMany(List<String> logStrings) async {
await _cloudWatch.log(logStrings);
}